LOAD {{ PWS_PROFILE2 }}
PANE
OPER
VISC {{ PWS_POL_REYNOLDS }}
ITER {{ PWS_POL_ITER }}
MACH {{ PWS_POL_MACH }}
PACC
{{ PWS_POLAR_FILE }}

ASEQ {{ PWS_POL_ALPHA_START }} {{ PWS_POL_ALPHA_END }} {{ PWS_POL_ALPHA_STEP }}

PACC
QUIT