(define globmin {{ MSH_GLOBMIN }})
(define proxmin {{ MSH_PROXMIN }})
(define curvmin {{ MSH_CURVMIN }})
(define curvmax {{ MSH_CURVMAX }})
(define globmax {{ MSH_GLOBMAX }})
(define nprisms {{ MSH_NPRISMS }})
(define firstCellHeight {{ MSH_FIRSTCELLHEIGHT }})
(define mpx {{ MSH_MPX }})
(define mpy {{ MSH_MPY }})
(define mpz {{ MSH_MPZ }})
(define parallel-tet-beta? {{ MSH_PARALLEL_TET_BETA | string | lower }})
(define rotational-periodic? {{ MSH_ROTATIONAL_PERIODIC | string | lower }})
(define periodicAngle {{ MSH_PERIODIC_ANGLE }})
(define periodicAxisX {{ MSH_PERIODIC_AXIS_X }})
(define periodicAxisY {{ MSH_PERIODIC_AXIS_Y }})
(define periodicAxisZ {{ MSH_PERIODIC_AXIS_Z }})
(define periodicZones "{{ MSH_PERIODIC_ZONES }}")
(define translational-periodic? {{ MSH_TRANSLATIONAL_PERIODIC | string | lower }})
(define periodicTranslationVx {{ MSH_PERIODIC_TRANSLATION_VX }})
(define periodicTranslationVy {{ MSH_PERIODIC_TRANSLATION_VY }})
(define periodicTranslationVz {{ MSH_PERIODIC_TRANSLATION_VZ }})
(define periodicTranslationZones "{{ MSH_PERIODIC_TRANSLATION_ZONES }}")
(define remesh-2d? {{ MSH_REMESH_2D | string | lower }})
(define z-span {{ MSH_Z_SPAN }})
