# Veusz saved document (version 3.6.2)
# Saved at 2025-06-24T12:53:12.974917

SetCompatLevel(1)
AddImportPath('C:\\Users\\Noel\\Documents\\GitHub\\Pipeline\\01_XFOIL\\img')
ImportFile('{{ PRF_PROFILE1 }}', 'a,b', ignoretext=True, linked=True)
ImportFile('{{ PRF_PROFILE2 }}', 'x,y', ignoretext=True, linked=True)
Set('StyleSheet/axis-function/autoRange', 'next-tick')
Add('page', name='page1', autoadd=False)
To('page1')
Set('width', '21cm')
Set('height', '15cm')
Add('grid', name='grid1', autoadd=False)
To('grid1')
Set('rows', 2)
Set('columns', 1)
Add('graph', name='graph2', autoadd=False)
To('graph2')
Set('aspect', 4.0)
Add('axis', name='x', autoadd=False)
Add('axis', name='y', autoadd=False)
To('y')
Set('min', -0.1)
Set('max', 0.15)
Set('direction', 'vertical')
Set('GridLines/style', 'solid')
Set('GridLines/hide', True)
Set('MinorGridLines/style', 'solid')
Set('MinorGridLines/hide', True)
To('..')
Add('xy', name='xy3', autoadd=False)
To('xy3')
Set('marker', 'dot')
Set('markerSize', '3pt')
Set('color', 'red')
Set('xData', 'x')
Set('yData', 'y')
Set('PlotLine/color', 'red')
Set('PlotLine/width', '1pt')
Set('MarkerLine/color', 'red')
Set('MarkerLine/width', '2pt')
Set('MarkerLine/hide', False)
Set('MarkerFill/hide', False)
Set('MarkerFill/newMarkerSizes', True)
To('..')
To('..')
Add('graph', name='graph1', autoadd=False)
To('graph1')
Set('aspect', 4.0)
Add('axis', name='x', autoadd=False)
To('x')
Set('GridLines/hide', True)
Set('MinorGridLines/hide', True)
To('..')
Add('axis', name='y', autoadd=False)
To('y')
Set('min', -0.1)
Set('max', 0.15)
Set('direction', 'vertical')
Set('GridLines/style', 'solid')
Set('GridLines/hide', True)
Set('MinorGridLines/style', 'solid')
Set('MinorGridLines/hide', True)
To('..')
Add('xy', name='xy2', autoadd=False)
To('xy2')
Set('marker', 'dot')
Set('markerSize', '3pt')
Set('color', 'blue')
Set('xData', 'a')
Set('yData', 'b')
Set('PlotLine/color', 'blue')
Set('PlotLine/width', '1pt')
Set('MarkerLine/color', 'blue')
Set('MarkerLine/width', '2pt')
Set('MarkerLine/hide', False)
Set('MarkerFill/color', 'blue')
Set('MarkerFill/hide', False)
Set('MarkerFill/newMarkerSizes', True)
To('..')
To('..')
To('..')
To('..')
