
# Category: Global

 FSP_INPUT_FILE_VERSION 242

# Category: Files

 DRP_RESTART_FILE
 FSP_FILE_CONVERGENCE converg
 FSP_FILE_CRYSTAL_SOLUTION_MULTI "Distribution.*/crystal"
 FSP_FILE_DISPLACEMENT timebc.dat
 FSP_FILE_OUTPUT_LOG out
 FSP_FILE_SOLUTION_RESTART "../run_FENSAP/soln"
 FSP_GUI_VAPOR_RESTART_FLAG 0
 FSP_INPUT_FILE_FORMAT 1
 FSP_INPUT_FORCES "../run_FENSAP/surface.dat"
 FSP_OUTPUT_FILE_FORMAT 1
 FSP_UNIT_ACTUATOR_DISK disk_data.dat
 GLB_FILE_DROPLET_SOLUTION droplet
 GLB_FILE_GRID "../GCI.grid"

# Category: Grid GUI metadata

 FSP_GUI_ITYP_BC_COLORS_B 3 53 128 255
 FSP_GUI_ITYP_BC_COLORS_G 3 53 128 0
 FSP_GUI_ITYP_BC_COLORS_R 3 255 128 0

# Category: Geometrical characteristics
FSP_CHARAC_LENGTH {{ FSP_CHARAC_LENGTH }}

# Category: Parameters for time-accurate scheme
DRP_GUI_CFL {{ DRP_GUI_CFL }}
FSP_DIMENSIONAL_TIME_STEP {{ FSP_DIMENSIONAL_TIME_STEP }}
FSP_GUI_CFL {{ FSP_GUI_CFL }}
FSP_GUI_DROP_MAX_TIME_STEPS_PER_CYCLE {{ FSP_GUI_DROP_MAX_TIME_STEPS_PER_CYCLE }}
FSP_GUI_FENSAP_MAX_TIME_STEPS_PER_CYCLE {{ FSP_GUI_FENSAP_MAX_TIME_STEPS_PER_CYCLE }}
FSP_GUI_VARIABLE_RELAXATION {{ FSP_GUI_VARIABLE_RELAXATION }}
FSP_INVERSE_CFL {{ FSP_INVERSE_CFL }}
FSP_MAX_NEWTON_ITERATIONS_PER_CYCLE {{ FSP_MAX_NEWTON_ITERATIONS_PER_CYCLE }}
FSP_MAX_TIME_STEPS_PER_CYCLE {{ FSP_MAX_TIME_STEPS_PER_CYCLE }}
FSP_TIME_ACCURATE_SCHEME_ORDER {{ FSP_TIME_ACCURATE_SCHEME_ORDER }}
FSP_TOTAL_SIMULATION_TIME {{ FSP_TOTAL_SIMULATION_TIME }}

# Category: Parameter cycles
DRP_GUI_ARTIFICIAL_VISCOSITY_IN_RESIDUAL {{ DRP_GUI_ARTIFICIAL_VISCOSITY_IN_RESIDUAL }}
FSP_ARTIFICIAL_VISCOSITY_IN_RESIDUAL {{ FSP_ARTIFICIAL_VISCOSITY_IN_RESIDUAL }}
FSP_CYCLES_CONVERGENCE_CUTOFF {{ FSP_CYCLES_CONVERGENCE_CUTOFF }}
FSP_GUI_CYCLE1_AV_CUTOFF {{ FSP_GUI_CYCLE1_AV_CUTOFF }}
FSP_NUMBER_OF_PARAMETER_CYCLES {{ FSP_NUMBER_OF_PARAMETER_CYCLES }}
FSP_RELAXATION_FACTOR_FOR_K_EPSILON_TURBULENCE_MODEL {{ FSP_RELAXATION_FACTOR_FOR_K_EPSILON_TURBULENCE_MODEL }}

# Category: Equations parameters
FSP_DROPLET_EQUATIONS {{ FSP_DROPLET_EQUATIONS }}
FSP_ENERGY_EQUATION {{ FSP_ENERGY_EQUATION }}
FSP_GOVERNING_EQUATIONS {{ FSP_GOVERNING_EQUATIONS }}
FSP_GUI_SOLVER_MODE {{ FSP_GUI_SOLVER_MODE }}
FSP_GUI_SOLVER_MODE_PROXY {{ FSP_GUI_SOLVER_MODE_PROXY }}

# Category: Reference conditions AIR
FSP_FREESTREAM_PRESSURE {{ FSP_FREESTREAM_PRESSURE }}
FSP_FREESTREAM_TEMPERATURE {{ FSP_FREESTREAM_TEMPERATURE }}
FSP_FREESTREAM_VELOCITY {{ FSP_FREESTREAM_VELOCITY }}
FSP_GUI_USE_INITIAL_TEMPERATURE {{ FSP_GUI_USE_INITIAL_TEMPERATURE }}
FSP_MACH_NUMBER {{ FSP_MACH_NUMBER }}
FSP_REYNOLDS_NUMBER {{ FSP_REYNOLDS_NUMBER }}

# Category: Reference conditions DROPLET
FSP_FREESTREAM_DIAMETER {{ FSP_FREESTREAM_DIAMETER }}
FSP_FREESTREAM_LWC {{ FSP_FREESTREAM_LWC }}
FSP_WATER_DENSITY {{ FSP_WATER_DENSITY }}
GLB_GUI_APPENDIX_SWITCH {{ GLB_GUI_APPENDIX_SWITCH }}
GLB_GUI_USE_APPENDIX_C {{ GLB_GUI_USE_APPENDIX_C }}
GLB_GUI_USE_APPENDIX_C_LWC_FACTOR {{ GLB_GUI_USE_APPENDIX_C_LWC_FACTOR }}
GLB_GUI_USE_APPENDIX_D {{ GLB_GUI_USE_APPENDIX_D }}
GLB_GUI_USE_APPENDIX_D_TWC_FACTOR {{ GLB_GUI_USE_APPENDIX_D_TWC_FACTOR }}
GLB_GUI_USE_APPENDIX_O {{ GLB_GUI_USE_APPENDIX_O }}
GLB_GUI_USE_APPENDIX_O_LWC_FACTOR {{ GLB_GUI_USE_APPENDIX_O_LWC_FACTOR }}

# Category: Imposed velocities for AIR
FSP_VELOCITY_X {{ FSP_VELOCITY_X }}
FSP_VELOCITY_Y {{ FSP_VELOCITY_Y }}
FSP_VELOCITY_Z {{ FSP_VELOCITY_Z }}

# Category: Imposed velocities for DROPLET
DRP_GUI_INITIAL_TYPE {{ DRP_GUI_INITIAL_TYPE }}
FSP_DROPLET_INITIAL_VEL {{ FSP_DROPLET_INITIAL_VEL }}
FSP_GUI_DROPLET_INITIAL_VEL_COMP_X {{ FSP_GUI_DROPLET_INITIAL_VEL_COMP_X }}
FSP_GUI_DROPLET_INITIAL_VEL_COMP_Y {{ FSP_GUI_DROPLET_INITIAL_VEL_COMP_Y }}
FSP_GUI_DROPLET_INITIAL_VEL_COMP_Z {{ FSP_GUI_DROPLET_INITIAL_VEL_COMP_Z }}

# Category: Gravity and rotation
FSP_GRAVITY {{ FSP_GRAVITY }}
FSP_GUI_BODY_FORCES {{ FSP_GUI_BODY_FORCES }}

# Category: Boundary conditions
FSP_BC_SUBTYPE {{ FSP_BC_SUBTYPE }}
FSP_GUI_ITYP_BC_NAMES {{ FSP_GUI_ITYP_BC_NAMES }}
FSP_ITYP {{ FSP_ITYP }}
FSP_TOT_BOUNDARY_CONDITIONS {{ FSP_TOT_BOUNDARY_CONDITIONS }}


# Category: Boundary conditions settings
FSP_CONTOUR_PRESS {{ FSP_CONTOUR_PRESS }}
FSP_GUI_BC_INLET_SUPERSONIC_FLAG {{ FSP_GUI_BC_INLET_SUPERSONIC_FLAG }}
FSP_GUI_BC_OUTLET_SUPERSONIC_FLAG {{ FSP_GUI_BC_OUTLET_SUPERSONIC_FLAG }}
FSP_GUI_ICE_WALL_CONDUCTIVITY {{ FSP_GUI_ICE_WALL_CONDUCTIVITY }}
FSP_GUI_ICE_WALL_INTERNAL_TEMPERATURE {{ FSP_GUI_ICE_WALL_INTERNAL_TEMPERATURE }}
FSP_GUI_ICE_WALL_THICKNESS {{ FSP_GUI_ICE_WALL_THICKNESS }}
FSP_GUI_INLET_ROTATION_TYPE {{ FSP_GUI_INLET_ROTATION_TYPE }}
FSP_GUI_IRS_NITER_PRE {{ FSP_GUI_IRS_NITER_PRE }}
FSP_GUI_IRS_NULL_PRE {{ FSP_GUI_IRS_NULL_PRE }}
FSP_GUI_IRS_PRES_END {{ FSP_GUI_IRS_PRES_END }}
FSP_GUI_IRS_PRES_START {{ FSP_GUI_IRS_PRES_START }}
FSP_GUI_IWT {{ FSP_GUI_IWT }}
FSP_GUI_PRESSURE_CONTOUR_INTEGRALS_INDEX {{ FSP_GUI_PRESSURE_CONTOUR_INTEGRALS_INDEX }}
FSP_GUI_RADIAL_EQUILIBRIUM_FLAG {{ FSP_GUI_RADIAL_EQUILIBRIUM_FLAG }}
FSP_GUI_TURB1 {{ FSP_GUI_TURB1 }}
FSP_GUI_TURB2 {{ FSP_GUI_TURB2 }}
FSP_GUI_WALL_OMX_DETECTED {{ FSP_GUI_WALL_OMX_DETECTED }}
FSP_GUI_WALL_OMY_DETECTED {{ FSP_GUI_WALL_OMY_DETECTED }}
FSP_GUI_WALL_OMZ_DETECTED {{ FSP_GUI_WALL_OMZ_DETECTED }}
FSP_GUI_WALL_OM_MAGNITUDE {{ FSP_GUI_WALL_OM_MAGNITUDE }}
FSP_GUI_WALL_ROTATION_TYPE {{ FSP_GUI_WALL_ROTATION_TYPE }}
FSP_IOPT {{ FSP_IOPT }}
FSP_IWHERE {{ FSP_IWHERE }}
FSP_OM_CENT_X {{ FSP_OM_CENT_X }}
FSP_OM_CENT_Y {{ FSP_OM_CENT_Y }}
FSP_OM_CENT_Z {{ FSP_OM_CENT_Z }}
FSP_PRESFIX {{ FSP_PRESFIX }}
FSP_PS {{ FSP_PS }}
FSP_PS_EQUATION {{ FSP_PS_EQUATION }}
FSP_QD {{ FSP_QD }}
FSP_QSWIT {{ FSP_QSWIT }}
FSP_RADIAL_EQUILIBRIUM_BOUNDARIES {{ FSP_RADIAL_EQUILIBRIUM_BOUNDARIES }}
FSP_RAD_EQ_NUMBER_OF_BANDS {{ FSP_RAD_EQ_NUMBER_OF_BANDS }}
FSP_RAD_EQ_REFPRESS_R_LOCATION {{ FSP_RAD_EQ_REFPRESS_R_LOCATION }}
FSP_TS {{ FSP_TS }}
FSP_TS_EQUATION {{ FSP_TS_EQUATION }}
FSP_VX {{ FSP_VX }}
FSP_VX_EQUATION {{ FSP_VX_EQUATION }}
FSP_VY {{ FSP_VY }}
FSP_VY_EQUATION {{ FSP_VY_EQUATION }}
FSP_VZ {{ FSP_VZ }}
FSP_VZ_EQUATION {{ FSP_VZ_EQUATION }}
FSP_WALL_OMX {{ FSP_WALL_OMX }}
FSP_WALL_OMY {{ FSP_WALL_OMY }}
FSP_WALL_OMZ {{ FSP_WALL_OMZ }}


# Category: Boundary conditions DROP
DRP_GUI_BC_DIAM {{ DRP_GUI_BC_DIAM }}
DRP_GUI_BC_DIAM_CRYSTALS {{ DRP_GUI_BC_DIAM_CRYSTALS }}
DRP_GUI_BC_DIAM_CRYSTALS_FLAG {{ DRP_GUI_BC_DIAM_CRYSTALS_FLAG }}
DRP_GUI_BC_DIAM_FLAG {{ DRP_GUI_BC_DIAM_FLAG }}
DRP_GUI_BC_LWC {{ DRP_GUI_BC_LWC }}
DRP_GUI_BC_LWC_CRYSTALS_FLAG {{ DRP_GUI_BC_LWC_CRYSTALS_FLAG }}
DRP_GUI_BC_LWC_FLAG {{ DRP_GUI_BC_LWC_FLAG }}
DRP_GUI_BC_MELTF_CRYSTALS_FLAG {{ DRP_GUI_BC_MELTF_CRYSTALS_FLAG }}
DRP_GUI_BC_TEMP {{ DRP_GUI_BC_TEMP }}
DRP_GUI_BC_TEMP_CRYSTALS_FLAG {{ DRP_GUI_BC_TEMP_CRYSTALS_FLAG }}
DRP_GUI_BC_TEMP_FLAG {{ DRP_GUI_BC_TEMP_FLAG }}
DRP_GUI_BC_VAPOR_INIT_TYPE {{ DRP_GUI_BC_VAPOR_INIT_TYPE }}
DRP_GUI_BC_VAP_CONC {{ DRP_GUI_BC_VAP_CONC }}
DRP_GUI_BC_VAP_CONC_FLAG {{ DRP_GUI_BC_VAP_CONC_FLAG }}
DRP_GUI_BC_VAP_RH {{ DRP_GUI_BC_VAP_RH }}
DRP_GUI_BC_VAP_RH_FLAG {{ DRP_GUI_BC_VAP_RH_FLAG }}
DRP_GUI_BC_VAP_WETBULB {{ DRP_GUI_BC_VAP_WETBULB }}
DRP_GUI_BC_VAP_WETBULB_FLAG {{ DRP_GUI_BC_VAP_WETBULB_FLAG }}
DRP_GUI_BC_VX {{ DRP_GUI_BC_VX }}
DRP_GUI_BC_VX_CRYSTALS_FLAG {{ DRP_GUI_BC_VX_CRYSTALS_FLAG }}
DRP_GUI_BC_VX_FLAG {{ DRP_GUI_BC_VX_FLAG }}
DRP_GUI_BC_VY {{ DRP_GUI_BC_VY }}
DRP_GUI_BC_VY_CRYSTALS_FLAG {{ DRP_GUI_BC_VY_CRYSTALS_FLAG }}
DRP_GUI_BC_VY_FLAG {{ DRP_GUI_BC_VY_FLAG }}
DRP_GUI_BC_VZ {{ DRP_GUI_BC_VZ }}
DRP_GUI_BC_VZ_CRYSTALS_FLAG {{ DRP_GUI_BC_VZ_CRYSTALS_FLAG }}
DRP_GUI_BC_VZ_FLAG {{ DRP_GUI_BC_VZ_FLAG }}
FSP_REINJECTION_SURFACE {{ FSP_REINJECTION_SURFACE }}
FSP_VAPOR_WET_WALL {{ FSP_VAPOR_WET_WALL }}

# Category: Screen icing
FSP_GUI_BC_SCREEN_MODE {{ FSP_GUI_BC_SCREEN_MODE }}
FSP_GUI_BC_SURFACE_TYPE_FLAG {{ FSP_GUI_BC_SURFACE_TYPE_FLAG }}
FSP_WIRE_DIAMETER {{ FSP_WIRE_DIAMETER }}
FSP_WIRE_SPACING {{ FSP_WIRE_SPACING }}

# Category: Materials
FSP_GUI_ID_MAT_COLORS_B {{ FSP_GUI_ID_MAT_COLORS_B }}
FSP_GUI_ID_MAT_COLORS_G {{ FSP_GUI_ID_MAT_COLORS_G }}
FSP_GUI_ID_MAT_COLORS_R {{ FSP_GUI_ID_MAT_COLORS_R }}
FSP_GUI_ID_MAT_NAMES {{ FSP_GUI_ID_MAT_NAMES }}
FSP_GUI_IROTFUS_FLAG {{ FSP_GUI_IROTFUS_FLAG }}
FSP_GUI_ROT_FIX_FLAG {{ FSP_GUI_ROT_FIX_FLAG }}
FSP_ID_MAT {{ FSP_ID_MAT }}
FSP_ROT_FIX_FLAG {{ FSP_ROT_FIX_FLAG }}

# Category: Iterative solver control parameters
FSP_NS_CONVERGENCE_CRITERIA {{ FSP_NS_CONVERGENCE_CRITERIA }}
FSP_NS_KRYLOV_ITERATIONS {{ FSP_NS_KRYLOV_ITERATIONS }}
FSP_NS_MAX_SOLVER_ITERATIONS {{ FSP_NS_MAX_SOLVER_ITERATIONS }}
FSP_NS_PRECONDITIONER {{ FSP_NS_PRECONDITIONER }}

# Category: Energy solver control parameters
FSP_NRG_CONVERGENCE_CRITERIA {{ FSP_NRG_CONVERGENCE_CRITERIA }}
FSP_NRG_KRYLOV_ITERATIONS {{ FSP_NRG_KRYLOV_ITERATIONS }}
FSP_NRG_MAX_SOLVER_ITERATIONS {{ FSP_NRG_MAX_SOLVER_ITERATIONS }}

# Category: Turbulence solver control parameters
FSP_TUR_CONVERGENCE_CRITERIA {{ FSP_TUR_CONVERGENCE_CRITERIA }}

# Category: Drop solver control parameters
FSP_DROP_CONVERGENCE_CRITERIA {{ FSP_DROP_CONVERGENCE_CRITERIA }}
FSP_DROP_KRYLOV_ITERATIONS {{ FSP_DROP_KRYLOV_ITERATIONS }}
FSP_DROP_MAX_SOLVER_ITERATIONS {{ FSP_DROP_MAX_SOLVER_ITERATIONS }}
FSP_SUPG_COEF_1 {{ FSP_SUPG_COEF_1 }}
FSP_SUPG_COEF_2 {{ FSP_SUPG_COEF_2 }}
FSP_SUPG_TYPE {{ FSP_SUPG_TYPE }}

# Category: Turbulence
FSP_GUI_TURBULENCE_SWITCH_PREVIOUS {{ FSP_GUI_TURBULENCE_SWITCH_PREVIOUS }}
FSP_RELAXATION_FACTOR_FOR_TURBULENCE {{ FSP_RELAXATION_FACTOR_FOR_TURBULENCE }}
FSP_TURBULENCE_SWITCH {{ FSP_TURBULENCE_SWITCH }}

# Category: ALE
FSP_RIGID_MOTION_COEFFS {{ FSP_RIGID_MOTION_COEFFS }}

# Category: Message printing
DRP_GUI_ITERATIONS_BETWEEN_PRINTOUTS {{ DRP_GUI_ITERATIONS_BETWEEN_PRINTOUTS }}
DRP_GUI_PRINTOUT_MODE {{ DRP_GUI_PRINTOUT_MODE }}
FSP_DROP_PRINT_ITER_FLAG {{ FSP_DROP_PRINT_ITER_FLAG }}
FSP_TIME_STEPS_BETWEEN_PRINTOUTS {{ FSP_TIME_STEPS_BETWEEN_PRINTOUTS }}

# Category: Droplet parameters
DRP_GUI_CRYSTAL_DISTRIBUTION {{ DRP_GUI_CRYSTAL_DISTRIBUTION }}
DRP_GUI_DROPLET_DISTRIBUTION {{ DRP_GUI_DROPLET_DISTRIBUTION }}
DRP_GUI_DROPLET_NUMBER {{ DRP_GUI_DROPLET_NUMBER }}
DRP_GUI_USER_CRYSTAL_AR_DIST {{ DRP_GUI_USER_CRYSTAL_AR_DIST }}
DRP_GUI_USER_CRYSTAL_DIST {{ DRP_GUI_USER_CRYSTAL_DIST }}
DRP_GUI_USER_DROPLET_MVD {{ DRP_GUI_USER_DROPLET_MVD }}
DRP_GUI_USER_DROPLET_PERCENTILE {{ DRP_GUI_USER_DROPLET_PERCENTILE }}
DRP_GUI_USER_DROPLET_RUN_FLAG {{ DRP_GUI_USER_DROPLET_RUN_FLAG }}
FSP_BETA_CONVERGENCE {{ FSP_BETA_CONVERGENCE }}
FSP_DROPLET_DRAG_RELATION {{ FSP_DROPLET_DRAG_RELATION }}
FSP_DROP_DIRICHLET_WALL {{ FSP_DROP_DIRICHLET_WALL }}
FSP_DROP_PROJECTION {{ FSP_DROP_PROJECTION }}
FSP_DROP_TERMINAL_VELOCITY {{ FSP_DROP_TERMINAL_VELOCITY }}

# Category: Ice crystal parameters
FSP_VAPOR_SCHMIDT {{ FSP_VAPOR_SCHMIDT }}

# Category: Probes
FSP_NPROBES {{ FSP_NPROBES }}

# Category: FS
FSP_MAX_ENERGY_ITERATIONS_PER_CYCLE {{ FSP_MAX_ENERGY_ITERATIONS_PER_CYCLE }}
FSP_MFLOW_RLX {{ FSP_MFLOW_RLX }}

# Category: Turbomachinery
FSP_GUI_REINJECTION_FLAG {{ FSP_GUI_REINJECTION_FLAG }}
FSP_RADIAL_EQUILIBRIUM_ITER_NUM {{ FSP_RADIAL_EQUILIBRIUM_ITER_NUM }}
FSP_RADIAL_EQUILIBRIUM_ITER_START {{ FSP_RADIAL_EQUILIBRIUM_ITER_START }}
FSP_RAD_EQ_PRESS_END {{ FSP_RAD_EQ_PRESS_END }}
FSP_RAD_EQ_PRESS_START {{ FSP_RAD_EQ_PRESS_START }}

# Category: Undefined
FSP_FILE_GRID_TIMESTAMP {{ FSP_FILE_GRID_TIMESTAMP }}


