# Category: Aerothermodynamic
ICE_RECOVERY_FACTOR {{ ICE_RECOVERY_FACTOR }}
ICE_REF_AIR_PRESSURE {{ ICE_REF_AIR_PRESSURE }}
ICE_REF_TEMPERATURE {{ ICE_REF_TEMPERATURE }}
ICE_REF_VELOCITY {{ ICE_REF_VELOCITY }}
ICE_TEMPERATURE {{ ICE_TEMPERATURE }}

# Category: GUI
GLB_GUI_USE_APPENDIX_C {{ GLB_GUI_USE_APPENDIX_C }}
GLB_GUI_USE_APPENDIX_C_LWC_FACTOR {{ GLB_GUI_USE_APPENDIX_C_LWC_FACTOR }}
GLB_GUI_USE_APPENDIX_D {{ GLB_GUI_USE_APPENDIX_D }}
GLB_GUI_USE_APPENDIX_D_TWC_FACTOR {{ GLB_GUI_USE_APPENDIX_D_TWC_FACTOR }}
GLB_GUI_USE_APPENDIX_O {{ GLB_GUI_USE_APPENDIX_O }}
GLB_GUI_USE_APPENDIX_O_LWC_FACTOR {{ GLB_GUI_USE_APPENDIX_O_LWC_FACTOR }}
ICE_GUI_ALE_METHOD {{ ICE_GUI_ALE_METHOD }}
ICE_GUI_ALE_SUBITERATIONS {{ ICE_GUI_ALE_SUBITERATIONS }}
ICE_GUI_DISPLACEMENT_MODE {{ ICE_GUI_DISPLACEMENT_MODE }}
ICE_GUI_FM_TEMPLATE {{ ICE_GUI_FM_TEMPLATE }}
ICE_GUI_GENERATE_DISPLACED_MESH {{ ICE_GUI_GENERATE_DISPLACED_MESH }}
ICE_GUI_POST_SMOOTHING_ITER {{ ICE_GUI_POST_SMOOTHING_ITER }}
ICE_MACH_NUMBER {{ ICE_MACH_NUMBER }}
ICE_REYNOLDS_NUMBER {{ ICE_REYNOLDS_NUMBER }}

# Category: Physical model
ICE_DROP_DIAM {{ ICE_DROP_DIAM }}
ICE_EMISSIVITY {{ ICE_EMISSIVITY }}
ICE_GUI_BODY_FORCES {{ ICE_GUI_BODY_FORCES }}
ICE_GUI_FLUID_TYPE {{ ICE_GUI_FLUID_TYPE }}
ICE_LIQ_H2O_CONTENT {{ ICE_LIQ_H2O_CONTENT }}
ICE_REL_HUMID {{ ICE_REL_HUMID }}

# Category: Fluid properties
ICE_H2O_CP {{ ICE_H2O_CP }}
ICE_H2O_DENSITY {{ ICE_H2O_DENSITY }}
ICE_H2O_VISCOSITY {{ ICE_H2O_VISCOSITY }}
ICE_ICE_CONDUC {{ ICE_ICE_CONDUC }}
ICE_ICE_CP {{ ICE_ICE_CP }}
ICE_ICE_DENSITY {{ ICE_ICE_DENSITY }}
ICE_LAT_HEAT_EVAPOR {{ ICE_LAT_HEAT_EVAPOR }}
ICE_LAT_HEAT_FUSION {{ ICE_LAT_HEAT_FUSION }}
ICE_LAT_HEAT_SUBLIM {{ ICE_LAT_HEAT_SUBLIM }}
ICE_VARIABLE_DENSITY {{ ICE_VARIABLE_DENSITY }}

# Category: Crystals
ICE_CRYSTAL_COEFFICIENT {{ ICE_CRYSTAL_COEFFICIENT }}
ICE_CRYSTAL_CONTENT {{ ICE_CRYSTAL_CONTENT }}
ICE_DEPOSITION_VARIANT {{ ICE_DEPOSITION_VARIANT }}


# Category: Numerical
ICE_AUTOMATIC_TIME_STEP {{ ICE_AUTOMATIC_TIME_STEP }}
ICE_BC_SINK {{ ICE_BC_SINK }}
ICE_CHARAC_LENGTH {{ ICE_CHARAC_LENGTH }}
ICE_FLUX_CHOICE {{ ICE_FLUX_CHOICE }}
ICE_FREEZING_FRACTION {{ ICE_FREEZING_FRACTION }}
ICE_GROWTH_DIRECTION {{ ICE_GROWTH_DIRECTION }}
ICE_GUI_CONCAVITY_FIX_FLAG {{ ICE_GUI_CONCAVITY_FIX_FLAG }}
ICE_GUI_GRID_OUTPUT_FLAG {{ ICE_GUI_GRID_OUTPUT_FLAG }}
ICE_GUI_INITIAL_TIME {{ ICE_GUI_INITIAL_TIME }}
ICE_GUI_TOTAL_TIME {{ ICE_GUI_TOTAL_TIME }}
ICE_MIN_CONCAVE_ANGLE {{ ICE_MIN_CONCAVE_ANGLE }}
ICE_NB_SINK {{ ICE_NB_SINK }}
ICE_NUMBER_TIME_STEP {{ ICE_NUMBER_TIME_STEP }}
ICE_SHAPE_SMOOTHING_ITERATIONS {{ ICE_SHAPE_SMOOTHING_ITERATIONS }}
ICE_SURFACE_THICKNESS_METHOD {{ ICE_SURFACE_THICKNESS_METHOD }}
ICE_TIME_STEP {{ ICE_TIME_STEP }}

# Category: Stress solver
SMC_FILL_IN_ALLOWED_IN_PRECONDITIONING_MATRIX {{ SMC_FILL_IN_ALLOWED_IN_PRECONDITIONING_MATRIX }}
SMC_PRECONDITIONER {{ SMC_PRECONDITIONER }}

# Category: Printout
ICE_GUI_NUMBERED_OUTPUT {{ ICE_GUI_NUMBERED_OUTPUT }}
ICE_GUI_TIME_BETWEEN_OUTPUT {{ ICE_GUI_TIME_BETWEEN_OUTPUT }}
ICE_IPS_LOAD {{ ICE_IPS_LOAD }}
ICE_OUTPUT_FORMAT {{ ICE_OUTPUT_FORMAT }}
ICE_TIME_STEP_BETWEEN_OUTPUT {{ ICE_TIME_STEP_BETWEEN_OUTPUT }}

# Category: Files
ICE_AIR_FILE {{ ICE_AIR_FILE }}
ICE_ANTI_ICING_FILE {{ ICE_ANTI_ICING_FILE }}
ICE_CHT3D_FORMAT {{ ICE_CHT3D_FORMAT }}
ICE_CONVERGENCE_FILE {{ ICE_CONVERGENCE_FILE }}
ICE_CRYSTAL_FILE {{ ICE_CRYSTAL_FILE }}
ICE_DISPLACED_GRID_FILE {{ ICE_DISPLACED_GRID_FILE }}
ICE_DROPLET_FILE {{ ICE_DROPLET_FILE }}
ICE_FORCE_FILE {{ ICE_FORCE_FILE }}
ICE_GRID_FILE {{ ICE_GRID_FILE }}
ICE_GUI_USE_FORCE_FILE {{ ICE_GUI_USE_FORCE_FILE }}
ICE_GUI_USE_RESTART_FILE {{ ICE_GUI_USE_RESTART_FILE }}
ICE_INPUT_FORMAT {{ ICE_INPUT_FORMAT }}
ICE_LOG_FILE {{ ICE_LOG_FILE }}
ICE_OUTPUT_BC {{ ICE_OUTPUT_BC }}
ICE_OUTPUT_GRID {{ ICE_OUTPUT_GRID }}
ICE_OUTPUT_MAP {{ ICE_OUTPUT_MAP }}
ICE_OUTPUT_STL {{ ICE_OUTPUT_STL }}
ICE_OUTPUT_TIN {{ ICE_OUTPUT_TIN }}
ICE_RESTART_FILE {{ ICE_RESTART_FILE }}
ICE_SOLUTION_FILE {{ ICE_SOLUTION_FILE }}


# Category: Other
ICE_AIR_CP {{ ICE_AIR_CP }}
ICE_BOLTZMANN {{ ICE_BOLTZMANN }}
ICE_TIME_SCHEME {{ ICE_TIME_SCHEME }}

# Category: Boundary conditions
FSP_BC_SUBTYPE {{ FSP_BC_SUBTYPE }}
FSP_GUI_BC_SCREEN_MODE {{ FSP_GUI_BC_SCREEN_MODE }}
FSP_GUI_BC_SURFACE_TYPE_FLAG {{ FSP_GUI_BC_SURFACE_TYPE_FLAG }}
FSP_QD {{ FSP_QD }}
FSP_QSWIT {{ FSP_QSWIT }}
FSP_TS {{ FSP_TS }}
FSP_WIRE_SPACING {{ FSP_WIRE_SPACING }}
ICE_BC_FAMILY {{ ICE_BC_FAMILY }}
ICE_GRID_FILE_WALL_ZONES {{ ICE_GRID_FILE_WALL_ZONES }}
ICE_GUI_BCLIST {{ ICE_GUI_BCLIST }}
ICE_GUI_BCWALL_FLAG {{ ICE_GUI_BCWALL_FLAG }}
ICE_GUI_BCWALL_HFLUX_FLAG {{ ICE_GUI_BCWALL_HFLUX_FLAG }}
ICE_GUI_BC_COLORS_B {{ ICE_GUI_BC_COLORS_B }}
ICE_GUI_BC_COLORS_G {{ ICE_GUI_BC_COLORS_G }}
ICE_GUI_BC_COLORS_R {{ ICE_GUI_BC_COLORS_R }}
ICE_GUI_BC_HFLUX {{ ICE_GUI_BC_HFLUX }}
ICE_GUI_BC_NAMES {{ ICE_GUI_BC_NAMES }}
ICE_GUI_CONDITIONS_COPIED {{ ICE_GUI_CONDITIONS_COPIED }}
ICE_GUI_MATLIST {{ ICE_GUI_MATLIST }}
ICE_GUI_WALL_OMX_DETECTED {{ ICE_GUI_WALL_OMX_DETECTED }}
ICE_GUI_WALL_OMY_DETECTED {{ ICE_GUI_WALL_OMY_DETECTED }}
ICE_GUI_WALL_OMZ_DETECTED {{ ICE_GUI_WALL_OMZ_DETECTED }}
ICE_GUI_WALL_OM_MAGNITUDE {{ ICE_GUI_WALL_OM_MAGNITUDE }}
ICE_GUI_WALL_ROTATION_TYPE {{ ICE_GUI_WALL_ROTATION_TYPE }}
ICE_ITYP {{ ICE_ITYP }}
ICE_NB_FAMILY {{ ICE_NB_FAMILY }}
ICE_OM_CENT_X {{ ICE_OM_CENT_X }}
ICE_OM_CENT_Y {{ ICE_OM_CENT_Y }}
ICE_OM_CENT_Z {{ ICE_OM_CENT_Z }}
ICE_TOT_BOUNDARY_CONDITIONS {{ ICE_TOT_BOUNDARY_CONDITIONS }}
ICE_WALL_CONDUCTIVITY {{ ICE_WALL_CONDUCTIVITY }}
ICE_WALL_INTERNAL_TEMPERATURE {{ ICE_WALL_INTERNAL_TEMPERATURE }}
ICE_WALL_OMX {{ ICE_WALL_OMX }}
ICE_WALL_OMY {{ ICE_WALL_OMY }}
ICE_WALL_OMZ {{ ICE_WALL_OMZ }}
ICE_WALL_THICKNESS {{ ICE_WALL_THICKNESS }}

# Category: External solver parameters
ICE_GUI_NCPU_MESHING {{ ICE_GUI_NCPU_MESHING }}
ICE_GUI_REMESHING_OPTION {{ ICE_GUI_REMESHING_OPTION }}

# Category: Undefined
ICE_FILE_GRID_TIMESTAMP {{ ICE_FILE_GRID_TIMESTAMP }}
ICE_INPUT_FILE_VERSION {{ ICE_INPUT_FILE_VERSION }}


